==> libminigui-4.0.5.tar.gz: libminigui-4.0.5/src/include/gal.h <==
///////////////////////////////////////////////////////////////////////////////
//
//                          IMPORTANT NOTICE
//
// The following open source license statement does not apply to any
// entity in the Exception List published by FMSoft.
//
// For more information, please visit:
//
// https://www.fmsoft.cn/exception-list
//
//////////////////////////////////////////////////////////////////////////////
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing 
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 * 
 *   Copyright (C) 2002~2018, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *   Or,
 * 
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 * 
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 * 
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/blog/minigui-licensing-policy/>.
 */
/*
** gal.h: the head file of Graphics Abstract Layer
**
** Create date: 2001/10/07
*/

#ifndef GUI_GAL_H
    #define GUI_GAL_H

#ifndef _MGRM_THREADS

extern BOOL __mg_switch_away; // always be zero for clients.

#ifdef _MGRM_PROCESSES
extern GHANDLE __mg_layer;

void unlock_draw_sem (void);
void lock_draw_sem (void);
#endif

#endif

#include "newgal.h"

#define WIDTHOFPHYSCREEN      WIDTHOFPHYGC
#define HEIGHTOFPHYSCREEN     HEIGHTOFPHYGC

#endif  /* GUI_GAL_H */

==> libminigui-5.0.12.tar.gz: libminigui-5.0.12/src/include/gal.h <==
///////////////////////////////////////////////////////////////////////////////
//
//                          IMPORTANT NOTICE
//
// The following open source license statement does not apply to any
// entity in the Exception List published by FMSoft.
//
// For more information, please visit:
//
// https://www.fmsoft.cn/exception-list
//
//////////////////////////////////////////////////////////////////////////////
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 *
 *   Copyright (C) 2002~2020, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 *
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *   Or,
 *
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 *
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 *
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/blog/minigui-licensing-policy/>.
 */
/*
** gal.h: the head file of Graphics Abstract Layer
**
** Create date: 2001/10/07
*/

#ifndef GUI_GAL_H
    #define GUI_GAL_H

// Since 5.0.0: available for all runtime modes.
extern BOOL __mg_switch_away;

#ifdef _MGRM_PROCESSES
extern GHANDLE __mg_layer;
#endif

#include "newgal.h"

#define WIDTHOFPHYSCREEN      WIDTHOFPHYGC
#define HEIGHTOFPHYSCREEN     HEIGHTOFPHYGC

#ifdef __cplusplus
extern "C" {
#endif  /* __cplusplus */

// Since 5.0.0
int __mg_convert_region_to_rects (const CLIPRGN * rgn,
        GAL_Rect *rects, int max_nr);

#ifdef __cplusplus
}
#endif  /* __cplusplus */

#endif  /* GUI_GAL_H */
